function [ psi ] = computePsiFromARMA( phi, theta, psi_len )
%[ psi ] = computePsiFromARMA( phi, theta, psi_len )
% Compute linear process representation, i.e. the coefficients of the polynomial psi(z) which approximates phi(z)/theta(z).
% We have to identify : (1 + theta_1*z + theta_2*z^2 + ... + theta_Q*z^Q)*(psi_0 + psi_1*z + psi_2*z^2 + ...) =
%                       (1 + phi_1*z + phi_2*z^2 + ... + phi_P)
% inputs:   phi: numerator coefficients phi(z)
%           theta: denominator coefficients theta(z)
%           psi_len: number of coefficients for psi(z)
% outputs:  psi: coefficients of psi(z) which approximates phi(z)/theta(z)

P = length(phi) - 1;
Q = length(theta) - 1;
phi_ext = zeros(psi_len+1,1);
phi_ext(1:P+1) = phi;
psi = zeros(psi_len+1,1);
psi(1) = 1;

for j=1:psi_len
    for k=1:Q
        if j-k>=0
            psi(j+1) = psi(j+1) - theta(k+1)*psi(j-k+1);
        end
    end
    psi(j+1) = psi(j+1) + phi_ext(j+1);
end


end

